package samples.files;

import com.asperasoft.faspmanager.FileInfo;
import com.asperasoft.faspmanager.SessionStats;
import com.asperasoft.faspmanager.TransferEvent;
import com.asperasoft.faspmanager.TransferListener;

/*
 *  Implementing a class derived from TransferListener is the way to check the progress
 *  of file transfers started with the FaspManager class.  This class is used by ALL the samples.
 */

public class FaspManagerListener implements TransferListener {

	private int		fileTransferCount;
	private boolean	sessionReady;

	public int getFileTransferCount() {
		return fileTransferCount;
	}

	public boolean isSessionReady() {
		return sessionReady;
	}

	/*
	 * The fileSessionEvent method of this class serves as a listener for the events generated by the fasp manager.
	 */
	@Override
	public synchronized void fileSessionEvent(TransferEvent event, SessionStats sessionStats, FileInfo currFileInfo) {
		switch (event) {
		case BANDWIDTH_MEASUREMENT:
			System.out.println("Measuring initial bandwidth...");
			break;
		case CONNECTING:
			System.out.println("Connecting...");
			break;
		case SESSION_START:
			sessionReady = true; // Session has started
			System.out.println("Session started. ID: " + sessionStats.getSessionId());
			System.out.println("XferId: " + sessionStats.getXferId());
			System.out.println("Tags: " + sessionStats.getTags());
			break;
		case FILE_START:
			System.out.println("File: " + currFileInfo.getName() + " started.");
			break;
		case PROGRESS:
			System.out.println("Progress "
					+ ProgressFormatter.stringPercentFromSizeFraction(
							currFileInfo.getWrittenBytes(), currFileInfo.getSizeBytes())
					+ " : "
					+
					ProgressFormatter.stringFromSizeFraction(currFileInfo.getWrittenBytes(), currFileInfo
							.getSizeBytes()) +
					" (" + ProgressFormatter.stringFromRate((long) (sessionStats.getTotalTransferredBytes() * 8 /
							(float) (sessionStats.getElapsedUSec() / (1000 * 1000)))) + ")");
			break;
		case RATE_MODIFICATION:
			System.out.println("Target transfer rate modified to: " +
					ProgressFormatter.stringFromRate(sessionStats.getTargetRateKbps()));
			System.out.println("(Minimum rate is: " +
					ProgressFormatter.stringFromRate(sessionStats.getMinRateKbps()) + ")");
			break;
		case FILE_STOP:
			fileTransferCount += 1;
			System.out.println("File: " + currFileInfo.getName() + " completed.");
			break;
		case SESSION_STOP:
			sessionReady = false; // Normal session end
			System.out.println("Session stopped ID: " + sessionStats.getId());
			break;
		case FILE_ERROR:
			fileTransferCount += 1;
			System.out.println("Error on file : " + currFileInfo.getName() + " Reason: "
					+ currFileInfo.getErrDescription());
			break;
		case SESSION_ERROR:
			sessionReady = false; // Session aborted abnormally
			System.out
					.println("Error in session ID: " + sessionStats.getId() + "  Reason: " + sessionStats.getErrorDescription());
			break;
		default:
			System.out.println("Unknown event received: " + event.toString() +
					" (" + event.getDescription() + ")");

		}

	}

}
